function I_cut = cutImageMargins(I)
% Cuts off the top and bottom margins of image I based on the average pixel
% values of its rows, and returns the remaining portion of the image.

% Inputs:
%   - I: the input image
%
% Output:
%   - I_cut: the cropped image

    % Calculate the average pixel value for each row
    row_averages = mean(I, 2);
    
    % Calculate the mean of the row averages
    mean_row_average = mean(row_averages);
    
    % Find the first and last rows with row averages greater than or equal to the mean
    top_row = find(row_averages >= mean_row_average, 1, 'first');
    bottom_row = find(row_averages >= mean_row_average, 1, 'last');
    
    % Cut the image to remove the top and bottom margins
    I_cut = I(top_row:bottom_row, :);

end
