function edge_spread = getEdgeSpread(binary_image)
% Calculates the edge spreading for each detected sine curve in the binary
% image, which represents the total number of pixels along a sinusoid and
% is a measure of how long the edge candidates spread in the core circumference.
%
% Inputs:
%   - binary_image: a binary image where the sine curves have been detected
%   - width: the width of the binary image
%
% Output:
%   - edge_spread: the length of the sine curves (in pixels) where the edges are detected

    % Count the number of edge pixels in each column of the binary image
    edge_counts = sum(binary_image, 1);
    
    % Determine which columns have at least one edge pixel
    edge_pixels = edge_counts > 0;
    
    % Sum the number of columns with edge pixels to get the edge spread
    edge_spread = sum(edge_pixels);
    
end
