function arc_length = getSineArcLength(amplitude, phase_shift, curve_width)
% Calculates the arc length of a sine curve based on its amplitude, phase shift, and width
%
% Inputs:
%   - amplitude: the amplitude of the sine curve
%   - phase_shift: the phase shift of the sine curve
%   - curve_width: the width of the sine curve (in pixels)
%
% Output:
%   - arc_length: the arc length of the sine curve (in pixels)

    % Define a function to calculate the integrand of the arc length equation
    integrand = @(x) sqrt(1 + (amplitude^2 * (2*pi / curve_width)^2 * cos(x + phase_shift).^2));
    
    % Calculate the arc length using the integral of the integrand
    arc_length = integral(integrand, 0, curve_width);
    
end
