function unwrap = unwrapCT(A,R)
% This function returns an unwrapped image from a cylindrical core CT image.
%
% Inputs:
%   A: 3D core XCT image
%   R: Diameter for unwrapped image (in px)
% Output:
%   unwrap: Unwrapped image

% Get image size and length
npix = size(A,1);
n = size(A,3);

% Create circular mask
center = npix/2;
pxc = ones(npix);
[ix, iy] = meshgrid(1:npix, 1:npix);
r = sqrt((ix-center).^2+(iy-center).^2);
pxc(r > R) = 0;

% Find boundaries
b = bwboundaries(pxc);
c = b{1,1};

% Extract unwrap image
unwrap = zeros(n, length(c));
for j = 1:n
    for k = 1:length(c)
        unwrap(j,k) = xy_slice(c(k,2), c(k,1));
    end
end
end
