function [y0,pmax] = y0Detection(I,ws,skip_y0,MPP,MPD)
% Offset (y0) detection based on a search strategy proposed by Changchun and Ge (2002)

% [Input]
% I        : Input binary image to be processed
% ws       : Window size to be investigated
% skip_y0  : Those values are not used for the peak picking
% MPP, MPD : Minimum peak prominence and minimum peak distance

% [Output]
% y0       : Determined offset y0
% pmax     : The highest value in the accumulator corresponding to the determined y0

[height,width] = size(I);

% Find the coordinates of the edge pixels on the left and right sides of the core
[y1,x1] = find(I);
for i = 1:length(x1)
    if x1(i) < round(width/2)
        x2(i) = x1(i) + round(width/2);        
    elseif x1(i) > round(width/2)
        x2(i) = x1(i) - round(width/2);
    else
        x2(i) = x1(i);
    end
end

% Calculate the accumulator values based on the detected edges
Accumulator = zeros(height,1);
for j = 1:length(x1)
    if y1(j) > ws && y1(j) <= height - ws
        yabove = y1(j) - ws;
        ybelow = y1(j) + ws;
        y2 = find(I(:,x2(j)));
        y2 = y2(y2 > yabove & y2 < ybelow);
        if isempty(y2) == 0
            yc = round((y1(j) + y2)/2); 
            Accumulator(yc) = Accumulator(yc) + 1;
        end
    end
end

% Find the peak of the accumulator values
Accumulator(skip_y0) = NaN;
p = findpeaks(Accumulator,'MinPeakProminence',MPP,'MinPeakDistance',MPD);
if isempty(p) == 1
    pmax = 0;
    y0 = 0;
else
    pmax = max(p);
    pmax = pmax(1);
    y0 = find(Accumulator == pmax,1,'first');
end
